package L20_pkg;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.geom.Rectangle2D;

import javax.swing.JPanel;

/**
 * This class encapsulates a JPanel child that consists of a drawing canvas for
 * a PolkaDotDataModel. The polka dots that are specified in the data model are
 * drawn on the canvas. The component does not specify a preferred initial size
 * and instead is sized to fit the root container.
 * 
 * @author mb
 * 
 */
public class CanvasPanel extends JPanel {

	private PolkaDotDataModel myDataModel;

	/**
	 * Constructor
	 */
	public CanvasPanel(PolkaDotDataModel myDataModel) {
		/*
		 * the line below would be invoked by default even it we hadn't
		 * specified it. This corresponds to the constructor JPanel() [see API]
		 */
		super();
		this.myDataModel = myDataModel;
	}

	/**
	 * This method implements how this component should be drawn.
	 * 
	 * This method is called when the windowing system determines that the root
	 * component to which this component belongs should be re-rendered. The
	 * paint(Graphics g) method is invoked on the window's root component,
	 * which, in turn, invokes the paint(Graphics g) method on each of child
	 * components of the root (and recursively down the containment hierarchy).
	 * The component's paint(Graphics g) method, in turn, invokes the method,
	 * paintComponent(Graphics g) [which is this method].
	 * 
	 * As well, this method causes a statement to be printed to the console
	 * "Component of view is repainting itself.."
	 * 
	 * Swing programs should override paintComponent() instead of overriding
	 * paint() [ref: http://java.sun.com/products/jfc/tsc/articles/painting/]
	 * 
	 */
	@Override
	public void paintComponent(Graphics g) {
		super.paintComponent(g);
		System.out.println("Component of view is repainting itself.");

		Graphics2D g2 = (Graphics2D) g;
		g2.setPaint(Color.WHITE);
		g2.fill(new Rectangle2D.Double(0, 0, this.getWidth(), this.getHeight()));

		for (PolkaDot dot : myDataModel.getDots()) {
			dot.drawComponent(g2);
		}

	}
}
