package L20_pkg;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Point;
import java.awt.geom.Ellipse2D;

/**
 * This class encapsulates a polka dot shape, which has a diameter, a color, and
 * a position.
 * 
 * @author mb
 * 
 */
public class PolkaDot {
	private Point center;
	private Color theColor;
	private int diameter;
	private static Color[] PALETTE = { Color.RED, Color.ORANGE, Color.YELLOW,
			Color.GREEN, Color.BLUE, Color.MAGENTA };

	/**
	 * Construct a polka dot with the specified attributes.
	 * 
	 * @param xPos
	 * @param yPos
	 * @param col
	 * @param diameter
	 */
	public PolkaDot(int xPos, int yPos, Color col, int diameter) {
		this.center = new Point(xPos, yPos);
		this.theColor = col;
		this.diameter = diameter;
	}

	/**
	 * Construct a polka dot with the specified attributes.
	 * 
	 * 
	 * @param point
	 * @param col
	 * @param diameter
	 */
	public PolkaDot(Point point, Color col, int diameter) {
		this.center = point;
		this.theColor = col;
		this.diameter = diameter;
	}

	/**
	 * Specify the color of this Polka Dot
	 * 
	 * @param theColor
	 */
	public void setTheColor(Color theColor) {
		this.theColor = theColor;
	}

	/**
	 * Get the color of this Polka Dot
	 * 
	 */
	public Color getTheColor() {
		return this.theColor;
	}

	/**
	 * This method causes this polka dot to be drawn on the passed Graphics2D
	 * objects.
	 * 
	 * 
	 * @param graphics2D
	 */
	public void drawComponent(Graphics2D graphics2D) {

		graphics2D.setStroke(new BasicStroke(3));
		graphics2D.setColor(this.getTheColor());
		graphics2D.draw(new Ellipse2D.Double(center.x, center.y, diameter,
				diameter));
	}

	/**
	 * This method generates a random polka dot, with a color randomly chosen
	 * among RGB and a position chosen randomly from within a palette of 6 basic
	 * colors (red, orange, yellow, green, blue, magenta). The diameter is
	 * chosen randomly from the interval [20,50]
	 * 
	 * @return
	 */
	public static PolkaDot getRandom(int xDim, int yDim) {
		final int MIN_DIA = 20;
		final int MAX_DIA = 50;
		int diameter = PolkaDot
				.getRandomIntFromClosedInterval(MIN_DIA, MAX_DIA);
		int xPos = PolkaDot.getRandomIntFromClosedInterval(0, xDim - diameter);
		int yPos = PolkaDot.getRandomIntFromClosedInterval(0, yDim - diameter);
		int colIdx = PolkaDot.getRandomIntFromClosedInterval(0,
				PALETTE.length - 1);
		return new PolkaDot(xPos, yPos, PALETTE[colIdx], diameter);
	}

	private static int getRandomIntFromClosedInterval(int minDesiredVal,
			int maxDesiredVal) {
		int randomVal = minDesiredVal
				+ (int) (Math.random() * (maxDesiredVal - minDesiredVal + 1));
		return randomVal;
	}

}
