package L20_pkg;

import java.awt.Color;
import java.awt.Dimension;
import java.util.List;
import java.util.Vector;

/**
 * This class encapsulates a data model of a collection of polka dots.
 * 
 * Duplicate polka dots are permitted.
 * 
 * @author mb
 * 
 */
public class PolkaDotDataModel {

	private List<PolkaDot> theDots;
	private List<ModelListener> listeners;

	/**
	 * Creates a collection and initialized it with three polka dots
	 */
	public PolkaDotDataModel() {
		listeners = new Vector<ModelListener>();
		theDots = new Vector<PolkaDot>();
		// here we add a few polka dots to populate the model with some initial
		// data
		this.addDot(new PolkaDot(30, 40, Color.RED, 30));
		this.addDot(new PolkaDot(50, 20, Color.MAGENTA, 20));
		this.addDot(new PolkaDot(100, 80, Color.GREEN, 50));
		notifyModelHasChanged();

	}

	/**
	 * Add a listener to this model.
	 * 
	 * @param listener
	 */
	public void addListener(ModelListener listener) {
		listeners.add(listener);
	}

	private void notifyModelHasChanged() {
		for (ModelListener listener : listeners) {
			listener.changed();
		}
	}

	/**
	 * Return this collection as a List of PolkaDot objects.
	 * 
	 * @return as described above
	 */
	public List<PolkaDot> getDots() {
		return theDots;
	}

	/**
	 * Add the passed polka dot to this collection. The model notifies its
	 * listeners (if any) that it has changed. As well, a statement is printed
	 * to the console "Model is changing."
	 * 
	 * @param theDot
	 *            a non-null Polka Dot object
	 */
	public void addDot(PolkaDot theDot) {
		theDots.add(theDot);
		System.out.println("Model is changing.");
		notifyModelHasChanged();
	}

}
